@@ -71,7 +71,7 @@ class ArgumentConversion:
             "event": (lambda x: x, True),
             "data": (lambda x: x.data, True),
             "payload": (lambda x: x.data, True),
-            "attributes": (lambda x: x, True),
+            "attributes": (lambda x: {k:x[k] for k in x}, True),
             "req": (lambda x: x, False),
             "request": (lambda x: x, False),
             "body": (lambda x: x.get_data(), False),
